<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

class Creativestyle_AmazonCheckout_Model_Logger
{
    const AMAZON_LOG_DIR            = 'amazonpayments' . DS . 'v2';

    const API_LOG_FILE              = 'api.log';
    const EXCEPTION_LOG_FILE        = 'exception.log';

    /**
     * Return instance of Amazon Pay config object
     *
     * @return Creativestyle_AmazonCheckout_Model_Config
     */
    protected function _getConfig()
    {
        /** @var Creativestyle_AmazonCheckout_Model_Config $config */
        $config = Mage::getSingleton('amazonpay/config');
        return $config;
    }

    /**
     * Return full path for the log file and creates missing folder if necessary
     *
     * @param string $logFile
     * @return string|null
     */
    protected function _getLogFilePath($logFile)
    {
        $logDir = Mage::getBaseDir('log') . DS . self::AMAZON_LOG_DIR;

        try {
            // @codingStandardsIgnoreStart
            if (!is_dir($logDir)) {
                mkdir($logDir, 0777, true);
            }
            // @codingStandardsIgnoreEnd
        } catch (Exception $e) {
            Mage::logException($e);
        }

        return $logDir . DS . $logFile;
    }

    /**
     * @param Exception $e
     */
    public function exception(Exception $e)
    {
        if ($this->_getConfig()->isLoggerActive()) {
            // @codingStandardsIgnoreStart
            if (($fileHandle = fopen($this->_getLogFilePath(self::EXCEPTION_LOG_FILE), 'a')) !== false) {
                /** @var Mage_Core_Model_Date $dateModel */
                $dateModel = Mage::getModel('core/date');
                $exceptionData = array(
                    'timestamp' => $dateModel->date('c'),
                    'exception' => get_class($e),
                    'message' => $e->getMessage(),
                    'code' => $e->getCode(),
                    'file' => $e->getFile(),
                    'line' => $e->getLine(),
                    'trace' => $e->getTrace(),
                    'version' => $this->_getConfig()->getVersion()
                );

                if ($e instanceof Creativestyle_AmazonCheckout_Exception) {
                    $exceptionData['uuid'] = $e->getUuid();
                }

                fwrite($fileHandle, json_encode($exceptionData) . PHP_EOL);
                fclose($fileHandle);
            }
            // @codingStandardsIgnoreEnd
        }
    }

    /**
     * @param array $callData
     */
    public function apiCall(array $callData)
    {
        if ($this->_getConfig()->isLoggerActive()) {
            // @codingStandardsIgnoreStart
            if (($fileHandle = fopen($this->_getLogFilePath(self::API_LOG_FILE), 'a')) !== false) {
                /** @var Mage_Core_Model_Date $dateModel */
                $dateModel = Mage::getModel('core/date');
                $callData['timestamp'] = $dateModel->date('c', $callData['timestamp']);
                $callData['version'] = $this->_getConfig()->getVersion();
                fwrite($fileHandle, json_encode($callData) . PHP_EOL);
                fclose($fileHandle);
            }
            // @codingStandardsIgnoreEnd
        }
    }
}
