<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

abstract class Creativestyle_AmazonCheckout_Model_System_Config_Source_Abstract
{
    protected $_options = array();

    /**
     * Return Amazon Checkout extension helper
     *
     * @return Creativestyle_AmazonCheckout_Helper_Data
     */
    protected function _getHelper()
    {
        /** @var Creativestyle_AmazonCheckout_Helper_Data $helper */
        $helper = Mage::helper('amazonpay');
        return $helper;
    }

    /**
     * Translate given text
     *
     * @param string $text
     * @return string
     */
    protected function __($text)
    {
        return $this->_getHelper()->__($text);
    }

    /**
     * Return options as value and label pairs array, eg.:
     * [
     *     {"value": 1, "label": "Label 1"},
     *     {"value": 2, "label": "Label 2"}
     * ]
     *
     * @return string[][]
     */
    public function toOptionArray()
    {
        return array_map(
            function ($value, $label) {
                return array(
                    'value' => $value,
                    'label' => $label
                );
            },
            array_keys($this->_options),
            $this->toArray()
        );
    }

    /**
     * Options getter
     *
     * @return string[]
     */
    public function toArray()
    {
        return array_map(array($this, '__'), $this->_options);
    }
}
