<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

class Creativestyle_AmazonCheckout_Model_Url
{
    const FRONT_NAME = 'amazonpay';

    const ROUTE_ADD_TO_CART = 'cart/add';
    const ROUTE_CHECKOUT_SESSION = 'checkout/session';
    const ROUTE_CHECKOUT = 'checkout';
    const ROUTE_SAVE_SHIPPING_METHOD = 'checkout/saveShippingMethod';
    const ROUTE_CHECKOUT_SAVE = 'checkout/save';
    const ROUTE_CHECKOUT_PLACE = 'checkout/place';
    const ROUTE_CHECKOUT_RESULT = 'checkout/result';
    const ROUTE_LOGIN = 'login';
    const ROUTE_COUPON_POST = 'checkout/couponPost';

    const PARAM_CHECKOUT_SESSION_ID = 'amazonCheckoutSessionId';

    /**
     * Return instance of the URL model
     *
     * @return Mage_Core_Model_Url
     */
    protected function _getUrlModel()
    {
        /** @var Mage_Core_Model_Url $urlModel */
        $urlModel = Mage::getSingleton('core/url');
        return $urlModel;
    }

    /**
     * Shorthand function for generating URLs with the common front name
     *
     * @param string $route
     * @param array|null $params
     * @return string
     */
    public function getUrl($route = '', $params = null)
    {
        return $this->_getUrlModel()->getUrl(
            sprintf('%s/%s', self::FRONT_NAME, $route),
            $params
        );
    }

    /**
     * Return URL for adding to cart XHR endpoint
     *
     * @return string
     * @api
     */
    public function getAddToCartUrl()
    {
        return $this->getUrl(self::ROUTE_ADD_TO_CART);
    }

    /**
     * Return URL for creating checkout session XHR endpoint
     *
     * @return string
     * @api
     */
    public function getCreateCheckoutSessionUrl()
    {
        return $this->getUrl(self::ROUTE_CHECKOUT_SESSION);
    }

    /**
     * Return URL for Amazon checkout page
     *
     * @return string
     * @api
     */
    public function getCheckoutUrl()
    {
        return $this->getUrl(self::ROUTE_CHECKOUT);
    }

    /**
     * Return URL for saving shipping method XHR endpoint
     *
     * @return string
     * @api
     */
    public function getSaveShippingMethodUrl()
    {
        return $this->getUrl(self::ROUTE_SAVE_SHIPPING_METHOD);
    }

    /**
     * Return URL for passing order's custom fields
     *
     * @return string
     * @api
     */
    public function getSaveOrderDataUrl()
    {
        return $this->getUrl(self::ROUTE_CHECKOUT_SAVE);
    }

    /**
     * Return URL for placing order
     *
     * @param string|null $checkoutSessionId
     * @return string
     * @api
     */
    public function getPlaceOrderUrl($checkoutSessionId = null)
    {
        return $this->getUrl(
            self::ROUTE_CHECKOUT_PLACE,
            $checkoutSessionId ? array(self::PARAM_CHECKOUT_SESSION_ID => $checkoutSessionId) : null
        );
    }

    /**
     * Return callback URL for Amazon checkout result
     *
     * @return string
     * @api
     */
    public function getCheckoutResultUrl()
    {
        return $this->getUrl(self::ROUTE_CHECKOUT_RESULT);
    }

    /**
     * Return callback URL for Amazon login
     *
     * @return string
     * @api
     */
    public function getSignInReturnUrl()
    {
        return $this->getUrl(self::ROUTE_LOGIN, array('_nosid' => true, '_current' => false));
    }

    /**
     * Return URL for handling discount coupons XHR endpoint
     *
     * @return string
     * @api
     */
    public function getCouponPostUrl()
    {
        return $this->getUrl(self::ROUTE_COUPON_POST);
    }
}
